@@ -35,14 +35,14 @@ context_document <- function(toc = FALSE,
                              number_sections = FALSE,
                              fig_width = 6.5,
                              fig_height = 4.5,
-                             fig_crop = TRUE,
+                             fig_crop = 'auto',
                              fig_caption = TRUE,
                              dev = "pdf",
                              df_print = "default",
                              template = NULL,
                              keep_tex = FALSE,
                              keep_md = FALSE,
-                             citation_package = c("none", "natbib", "biblatex"),
+                             citation_package = c("default", "natbib", "biblatex"),
                              includes = NULL,
                              md_extensions = NULL,
                              output_extensions = NULL,
