@@ -14,7 +14,7 @@
 #' the markdown syntax for citations in the
 #' \href{https://rmarkdown.rstudio.com/authoring_bibliographies_and_citations.html}{Bibliographies
 #' and Citations} article in the online documentation.
-#'@md
+#'
 #'@inheritParams output_format
 #'@param toc \code{TRUE} to include a table of contents in the output
 #'@param toc_depth Depth of headers to include in table of contents
@@ -71,7 +71,10 @@
 #'  Note that if you don't use the "default" template then some features of
 #'  \code{html_document} won't be available (see the Templates section below for
 #'  more details).
-#'@param css One or more css files to include
+#'@param css CSS and/or Sass files to include. Files with an extension of .sass
+#'  or .scss are compiled to CSS via `sass::sass()`. Also, if `theme` is a
+#'  [bslib::bs_theme()] object, Sass code may reference the relevant Bootstrap
+#'  Sass variables, functions, mixins, etc.
 #'@param includes Named list of additional content to include within the
 #'  document (typically created using the \code{\link{includes}} function).
 #'@param keep_md Keep the markdown file generated by knitting.
@@ -99,9 +102,9 @@
 #'  \if{html}{\out{(&#x1F517;)}}.
 #'
 #'  If you prefer an svg icon, you can also use one using for example a direct link or downloading it from
-#'  \url{https://material.io/resources/icons/}.
+#'  \url{https://fonts.google.com/icons}.
 #'  \preformatted{
-#'  /* From https://material.io/resources/icons/
+#'  /* From https://fonts.google.com/icons
 #'     Licence: https://www.apache.org/licenses/LICENSE-2.0.html */
 #'  a.anchor-section::before {
 #'    content: url(https://fonts.gstatic.com/s/i/materialicons/link/v7/24px.svg);
@@ -207,6 +210,7 @@
 #'
 #' render("input.Rmd", html_document(toc = TRUE))
 #' }
+#' @md
 #' @export
 html_document <- function(toc = FALSE,
                           toc_depth = 3,
@@ -330,23 +334,6 @@ html_document <- function(toc = FALSE,
   if (number_sections)
     args <- c(args, "--number-sections")
 
-  # additional sass/css
-  for (f in css) {
-    if (is_bs_theme(theme)) {
-      theme <- bslib::bs_add_rules(theme, sass::sass_file(f))
-      next
-    }
-    is_sass <- grepl("\\.s[ac]ss$", f)
-    if (is_sass) {
-      f <- sass::sass(
-        sass::sass_file(f),
-        output = sub("\\.s[ac]ss$", ".css", f),
-        options = sass::sass_options(output_style = "compressed")
-      )
-    }
-    args <- c(args, "--css", pandoc_path_arg(f, backslash = FALSE))
-  }
-
 
   # manage list of exit_actions (backing out changes to knitr options)
   exit_actions <- list()
@@ -500,6 +487,7 @@ html_document <- function(toc = FALSE,
                                      template = template,
                                      pandoc_args = pandoc_args,
                                      extra_dependencies = extra_dependencies,
+                                     css = css,
                                      ...)
   )
 }
