@@ -19,9 +19,10 @@
 #' @param transition Speed of slide transitions. This can be "default",
 #'   "slower", "faster", or a numeric value with a number of seconds (e.g. 0.5).
 #' @param analytics A Google analytics property ID.
-#'@param smart Produce typographically correct output, converting straight
+#' @param smart Produce typographically correct output, converting straight
 #'  quotes to curly quotes, \code{---} to em-dashes, \code{--} to en-dashes, and
 #'  \code{...} to ellipses.
+#' @param css One or more css files to include.
 #' @return R Markdown output format to pass to \code{\link{render}}.
 #' @details
 #'   See the \href{https://bookdown.org/yihui/rmarkdown/ioslides-presentation.html}{
@@ -318,7 +319,7 @@ ioslides_presentation <- function(number_sections = FALSE,
       logo_path <- logo
       if (!self_contained) {
         # use same extension as specified logo (default is png if unspecified)
-        logo_ext <- tools::file_ext(logo)
+        logo_ext <- xfun::file_ext(logo)
         if (nchar(logo_ext) < 1)
           logo_ext <- "png"
         logo_path <- file.path(files_dir, paste("logo", logo_ext, sep = "."))
