@@ -213,7 +213,10 @@ NULL
 #' environment).
 #' @param run_pandoc An option for whether to run pandoc to convert Markdown
 #' output.
-#' @param quiet An option to suppress printing of the pandoc command line.
+#' @param quiet An option to suppress printing during rendering from knitr,
+#'   pandoc command line and others. To only suppress printing of the last
+#'   "Output created: " message, you can set \code{rmarkdown.render.message} to
+#'   \code{FALSE}
 #' @param encoding Ignored. The encoding is always assumed to be UTF-8.
 #' @return
 #'   When \code{run_pandoc = TRUE}, the compiled document is written into
@@ -386,15 +389,15 @@ render <- function(input,
   oldwd <- setwd(dirname(abs_path(input)))
   on.exit(setwd(oldwd), add = TRUE)
 
-  # reset the name of the input file to be relative and calculate variations
-  # on the filename for our various intermediate targets
+  # reset the name of the input file to be relative and generete the name of
+  # the intermediate knitted file. The extension can be set as an option mainly for blogdown
+  # as `.md~` will be ignored.
   input <- basename(input)
   knit_input <- input
-  knit_output <- intermediates_loc(file_with_meta_ext(input, "knit", "md"))
-
+  knit_output <- intermediates_loc(
+    file_with_meta_ext(input, "knit", getOption("rmarkdown.knit.ext", "md"))
+  )
   intermediates <- c(intermediates, knit_output)
-  utf8_input <- intermediates_loc(file_with_meta_ext(input, "utf8", "md"))
-  intermediates <- c(intermediates, utf8_input)
 
   # track whether this was straight markdown input (to prevent keep_md later)
   md_input <- identical(tolower(xfun::file_ext(input)), "md")
@@ -472,7 +475,8 @@ render <- function(input,
     output_format <- output_format_from_yaml_front_matter(input_lines,
                                                           output_options,
                                                           output_format,
-                                                          output_yaml)
+                                                          output_yaml,
+                                                          output_file)
     output_format <- create_output_format(output_format$name,
                                           output_format$options)
   }
@@ -821,8 +825,6 @@ render <- function(input,
   }
   intermediates <- c(intermediates, intermediates_fig)
 
-  file.copy(input, utf8_input, overwrite = TRUE)
-
   if (run_pandoc) {
 
     perf_timer_start("pre-processor")
@@ -830,7 +832,7 @@ render <- function(input,
     # call any pre_processor
     if (!is.null(output_format$pre_processor)) {
       extra_args <- output_format$pre_processor(front_matter,
-                                                utf8_input,
+                                                input,
                                                 runtime,
                                                 knit_meta,
                                                 files_dir,
@@ -840,10 +842,14 @@ render <- function(input,
 
     # write shiny_prerendered_dependencies if we have them
     if (is_shiny_prerendered(runtime)) {
-      shiny_prerendered_append_dependencies(utf8_input,
+      shiny_prerendered_append_dependencies(input,
                                             shiny_prerendered_dependencies,
                                             files_dir,
                                             output_dir)
+      # indicate to Pandoc we are in a shiny prerendered document to activate
+      # specific parts in the template.
+      output_format$pandoc$args <- c(output_format$pandoc$args,
+                                     pandoc_variable_arg("shiny-prerendered"))
     }
 
     perf_timer_stop("pre-processor")
@@ -869,22 +875,24 @@ render <- function(input,
 
       # ensure we expand paths (for Windows where leading `~/` does
       # not get expanded by pandoc)
-      utf8_input <- path.expand(utf8_input)
-      output     <- path.expand(output)
+      input  <- path.expand(input)
+      output <- path.expand(output)
 
       pandoc_args <- output_format$pandoc$args
 
       # if Lua filters are provided, add the command line switch
       if (!is.null(lua_filters <- output_format$pandoc$lua_filters)) {
+        lua_env_vars <- xfun::set_envvar(c(RMARKDOWN_LUA_SHARED = pkg_file_lua("shared.lua")))
+        on.exit(xfun::set_envvar(lua_env_vars), add = TRUE)
         lua_filters <- pandoc_lua_filter_args(lua_filters)
       }
       pandoc_args <- c(lua_filters, pandoc_args)
 
       # in case the output format turns on the --file-scope flag, run its
       # file_scope function to split the input into multiple files
-      input_files <- utf8_input
+      input_files <- input
       if (!is.null(output_format$file_scope) &&
-          length(inputs <- output_format$file_scope(utf8_input)) > 1) {
+          length(inputs <- output_format$file_scope(input)) > 1) {
 
         # add the --file-scope option
         pandoc_args <- c(pandoc_args, "--file-scope")
@@ -892,7 +900,7 @@ render <- function(input,
         # write the split content into *.split.md files
         input_files <- unlist(lapply(inputs, function(input) {
           file <- file_with_meta_ext(input$name, "split", "md")
-          file <- file.path(dirname(utf8_input), file)
+          file <- file.path(dirname(input), file)
           write_utf8(input$content, file)
           file
         }))
@@ -903,7 +911,7 @@ render <- function(input,
 
       # if we don't detect any invalid shell characters in the
       # target path, then just call pandoc directly
-      if (!grepl(.shell_chars_regex, output) && !grepl(.shell_chars_regex, utf8_input)) {
+      if (!grepl(.shell_chars_regex, output) && !grepl(.shell_chars_regex, input)) {
         return(pandoc_convert(
           input_files, pandoc_to, output_format$pandoc$from, output,
           citeproc, pandoc_args, !quiet
@@ -931,7 +939,7 @@ render <- function(input,
 
       # construct output path (when passed only a file name to '--output',
       # pandoc seems to render in the same directory as the input file)
-      pandoc_output_tmp_path <- file.path(dirname(utf8_input), pandoc_output_tmp)
+      pandoc_output_tmp_path <- file.path(dirname(input), pandoc_output_tmp)
 
       # rename output file to desired location
       renamed <- suppressWarnings(file.rename(pandoc_output_tmp_path, output))
@@ -956,7 +964,7 @@ render <- function(input,
     # if the output format is LaTeX, first convert .md to .tex, and then convert
     # .tex to .pdf via latexmk() if PDF output is requested (in rmarkdown <=
     # v1.8, we used to call Pandoc to convert .md to .tex and .pdf separately)
-    if (output_format$pandoc$keep_tex || knitr::is_latex_output()) {
+    if (output_format$pandoc$keep_tex || pandoc_to %in% c("latex", "beamer")) {
       # do not use pandoc-citeproc if needs to build bibliography
       convert(texfile, run_citeproc && !need_bibtex)
       # patch the .tex output generated from the default Pandoc LaTeX template
@@ -981,7 +989,7 @@ render <- function(input,
     if (!is.null(intermediates_dir)) {
       intermediate_output <- file.path(intermediates_dir, basename(output_file))
       if (file.exists(intermediate_output)) {
-        file.rename(intermediate_output, output_file)
+        move_dir(intermediate_output, output_file)
       }
     }
 
@@ -992,12 +1000,12 @@ render <- function(input,
     # if there is a post-processor then call it
     if (!is.null(output_format$post_processor))
       output_file <- output_format$post_processor(front_matter,
-                                                  utf8_input,
+                                                  input,
                                                   output_file,
                                                   clean,
                                                   !quiet)
 
-    if (!quiet) {
+    if (!quiet && getOption('rmarkdown.render.message', TRUE)) {
       message("\nOutput created: ", relative_to(oldwd, output_file))
     }
 
