@@ -134,16 +134,21 @@ run <- function(file = "index.Rmd", dir = dirname(file), default_file = NULL,
   yaml_front <- if (length(target_file)) yaml_front_matter(target_file)
   runtime <- yaml_front$runtime
   theme <- render_args$output_options$theme
+  # Let shiny::getCurrentTheme() know about the yaml's theme, so
+  # things like `bslib::bs_themer()` can work with prerendered documents.
+  # Also note that we add the actual shiny::bootstrapLib() dependency
+  # inside the document's pre-processing hook so the 'last' version of
+  # the theme wins out
   if (length(target_file)) {
     format <- output_format_from_yaml_front_matter(read_utf8(target_file))
-    theme <- format$options$theme
+    set_current_theme(resolve_theme(format$options$theme))
   }
 
   # run using the requested mode
   if (is_shiny_prerendered(runtime)) {
 
     # get the pre-rendered shiny app
-    app <- shiny_prerendered_app(target_file, render_args = render_args, theme = theme)
+    app <- shiny_prerendered_app(target_file, render_args = render_args)
   } else {
 
     # add rmd_resources handler on start
@@ -158,7 +163,7 @@ run <- function(file = "index.Rmd", dir = dirname(file), default_file = NULL,
     # combine the user-supplied list of Shiny arguments with our own and start
     # the Shiny server; handle requests for the root (/) and any R markdown files
     # within
-    app <- shiny::shinyApp(ui = rmarkdown_shiny_ui(dir, default_file, theme),
+    app <- shiny::shinyApp(ui = rmarkdown_shiny_ui(dir, default_file),
                            uiPattern = "^/$|^/index\\.html?$|^(/.*\\.[Rr][Mm][Dd])$",
                            onStart = onStart,
                            server = rmarkdown_shiny_server(
@@ -317,7 +322,7 @@ rmarkdown_shiny_server <- function(dir, file, auto_reload, render_args) {
 }
 
 # create the Shiny UI function
-rmarkdown_shiny_ui <- function(dir, file, theme) {
+rmarkdown_shiny_ui <- function(dir, file) {
   function(req) {
     # map requests to / to requests for the default--index.Rmd, or another if
     # specified
@@ -339,8 +344,7 @@ rmarkdown_shiny_ui <- function(dir, file, theme) {
     tags$div(
       tags$head(
         tags$script(src = "rmd_resources/rmd_loader.js"),
-        tags$link(href = "rmd_resources/rmd_loader.css", rel = "stylesheet"),
-        shiny_bootstrap_lib(theme)
+        tags$link(href = "rmd_resources/rmd_loader.css", rel = "stylesheet")
       ),
 
       # Shiny shows the outer conditionalPanel as long as the document hasn't
@@ -586,3 +590,10 @@ read_shiny_deps <- function(files_dir) {
     list()
   }
 }
+
+
+# shiny:::setCurrentTheme() was added in 1.6 (we may export in next version)
+set_current_theme <- function(theme) {
+  set_theme <- asNamespace("shiny")$setCurrentTheme
+  if (is.function(set_theme)) set_theme(theme)
+}
