@@ -1,21 +1,9 @@
 #' Tufte handout format (PDF)
 #'
-#' Template for creating a handout according to the style of
-#' Edward R. Tufte and Richard Feynman.
-#'
-#' See the \href{https://rmarkdown.rstudio.com/tufte_handout_format.html}{online
+#' This function has been moved to the \pkg{tufte} package. Please use
+#' \code{tufte::tufte_handout} instead. See the
+#' \href{https://bookdown.org/yihui/rmarkdown/tufte-handouts.html}{online
 #' documentation} for additional details.
-#'
-#' Creating Tufte handout output from R Markdown requires that LaTeX be installed.
-#'
-#' R Markdown documents can have optional metadata that is used to generate a
-#' document header that includes the title, author, and date. For more details
-#' see the documentation on R Markdown \link[=rmd_metadata]{metadata}.
-#'
-#' R Markdown documents also support citations. You can find more information on
-#' the markdown syntax for citations in the
-#' \href{https://rmarkdown.rstudio.com/authoring_bibliographies_and_citations.html}{Bibliographies
-#' and Citations} article in the online documentation.
 #' @inheritParams pdf_document
 #' @export
 tufte_handout <- function(fig_width = 4,
@@ -29,6 +17,12 @@ tufte_handout <- function(fig_width = 4,
                           md_extensions = NULL,
                           pandoc_args = NULL) {
 
+  # TODO: remove tufte_handout from rmarkdown
+  if (!xfun::is_R_CMD_check()) warning(
+    'The function rmarkdown::tufte_handout() has been deprecated. Please use',
+    'tufte::tufte_handout instead.'
+  )
+
   # Confirm we have the tufte package available
   if (!requireNamespace("tufte", quietly = TRUE))
     stop("The 'tufte' package is required to render the tufte_handout format.")
