@@ -1,12 +1,15 @@
+# TODO: to remove when switching the package to edition 3
+local_edition(3)
+
 .generate_md_and_convert <- function(content, output_format) {
   input_file <- local_rmd_file(c("---\ntitle: Test\n---\n", content))
-  output_file <- withr::local_tempfile()
-  res <- rmarkdown::render(input_file, output_format = output_format, output_file = output_file, quiet = TRUE)
-  xfun::read_utf8(res)
+  .render_and_read(input_file, output_format = output_format)
 }
 
-# Lua filters exists only since pandoc 2.0
-skip_if_not_pandoc("2.0")
+# rmarkdown requires pandoc >= 2.1 to support Lua filters
+skip_if_not_pandoc("2.1")
+
+# TODO: At some point, change this file to test only the filter in a simple pandoc conversion without all the rendering ( ~ unit test for Lua filters)
 
 test_that("pagebreak Lua filters works", {
   rmd <- "# HEADER 1\n\\newpage\n# HEADER 2\n\\pagebreak\n# HEADER 3"
@@ -35,6 +38,42 @@ test_that("number_sections Lua filter works", {
   expect_identical(result[result %in% expected], expected)
 })
 
+test_that("latex-divs.lua works with HTML doc", {
+  rmd <- "::: custom\ncontent\n:::\n\n some other content"
+  res <- .generate_md_and_convert(rmd, "html_document")
+  expect_match(grep('custom', res, value = TRUE), '<div class="custom"')
+  rmd <- "::: {.custom #id}\ncontent\n:::\n\n some other content"
+  res <- .generate_md_and_convert(rmd, "html_document")
+  expect_match(grep('custom', res, value = TRUE), '<div id="id" class="custom">')
+  rmd <- "::: {.custom #id data-latex=''}\ncontent\n:::\n\n some other content"
+  res <- .generate_md_and_convert(rmd, "html_document")
+  expect_match(grep('custom', res, value = TRUE), '<div id="id" class="custom">')
+  rmd <- "::: {.custom #id latex=true}\ncontent\n:::\n\n some other content"
+  res <- .generate_md_and_convert(rmd, "html_document")
+  expect_match(grep('custom', res, value = TRUE), '<div id="id" class="custom">')
+  rmd <- "::: {.custom #id latex=1}\ncontent\n:::\n\n some other content"
+  res <- .generate_md_and_convert(rmd, "html_document")
+  expect_match(grep('custom', res, value = TRUE), '<div id="id" class="custom">')
+})
+
+test_that("latex-divs.lua works with LaTeX (PDF)", {
+  rmd <- "::: {.custom #id}\ncontent\n:::\n\n some other content"
+  res <- .generate_md_and_convert(rmd, "latex_document")
+  expect_false(any(grepl('custom', res)))
+  rmd <- "::: {.custom #id data-latex=''}\ncontent\n:::\n\n some other content"
+  res <- .generate_md_and_convert(rmd, "latex_document")
+  lines <- local({ i <- grep("custom", res); seq.int(i[1], i[2])})
+  expect_snapshot_output(cat(res[lines]))
+  rmd <- "::: {.custom #id latex=true}\ncontent\n:::\n\n some other content"
+  res <- .generate_md_and_convert(rmd, "latex_document")
+  lines <- local({ i <- grep("custom", res); seq.int(i[1], i[2])})
+  expect_snapshot_output(cat(res[lines]))
+  rmd <- "::: {.custom #id latex=1}\ncontent\n:::\n\n some other content"
+  res <- .generate_md_and_convert(rmd, "latex_document")
+  lines <- local({ i <- grep("custom", res); seq.int(i[1], i[2])})
+  expect_snapshot_output(cat(res[lines]))
+})
+
 test_that("formats have the expected Lua filter", {
   expect_filters <- function(format_fun, expected_filters) {
     filters <- basename(format_fun$pandoc$lua_filters)
